# Simple Facebook Messenger
This is an unofficial, simple library to provide basic communication with Facebooks Messenger API: https://developers.facebook.com/docs/messenger-platform/introduction

## Supported Features
* Send & receive messages
* Support for Buttons and QuickReplies
* Support for images

It is currently Work in progress, Pull Requests are more than welcome! Examples can be found in [examples/
](https://github.com/eknoes/simple-fbmessenger/tree/main/examples).

Uses: 
* [aiohttp](https://github.com/aio-libs/aiohttp), Apache Software License (Apache 2)